#----------------------------------------------------------------------
# vertical list
# - use vl_new to create new list
# - use vl_delete to delete existing list
#----------------------------------------------------------------------

#------------------------------
# vl_new - create new vertical text list
#    labels  = values selectable by the spinbox
#    cb      = callback to call when a list entry is clicked
#    r, g, b = normal text color
#    pr, pg, pb = text color when the button is pointed at by the mouse pointer
#    sr, sg, sb = text color when the mouse clicks on the text
#------------------------------

proc vl_new { name x y labels size cb r g b pr pg pb sr sg sb } {
    set txtVar [vl_txt $name]

    # create text list
    set $txtVar {}
    set i 0
    foreach l $labels {
	set id [gui add text $x $y $l \
		    -color $r $g $b \
		    -size $size \
		    -point "vl_point" \
		    -pointColor $pr $pg $pb \
		    -pressColor $sr $sg $sb \
                    -selectColor $sr $sg $sb \
		    -select "$cb $i" \
		    -shadow]

	# append the id onto the list of id's
	lappend $txtVar $id

	# count number of lines there are in label
	set numLines 1
	for {set li 0} {$li < [string length $l]} {set li [expr $li + 1]} {
	    set lc [string index $l $li]
	    if {$lc == "\n"} {
		set numLines [expr $numLines + 1]
	    }
	}

	# move onto the next row
	set y [expr $y - $numLines]

	# next index
	set i [expr $i + 1]
    }
}

#------------------------------
# vl_delete - delete all GUI objects and variables associated with a
#             vertical list
#------------------------------

proc vl_delete { name } {
    set txtVar [vl_txt $name]

    if {[info var $txtVar] != {}} {
	set txt [expr $$txtVar]
	foreach t $txt {
	    gui del $t
	}

	unset $txtVar
    }
}

#------------------------------
# vl_txt - get the name of the variable that contains the list of IDs
#          for the list of text
#------------------------------

proc vl_txt { name } {
    return "::vi_$name\_txt"
}

#------------------------------
# vl_point - dummy callback function that is called when text in the
#            list is pointed at by the mouse pointer
#------------------------------

proc vl_point {} {
}

#----------------------------------------------------------------------
# test driver
#----------------------------------------------------------------------

# set labels [list zero one two three four five]
# set size 14
# 
# proc cb { arg } {
#     puts "test $arg"
# }
# 
# vl_new test 2 10 $labels $size cb 1 1 1 1 0 0 1 1 0
